==> igniteui-react-16.16.2.tgz: package/esm5/lib/DropdownGroup.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { DropdownGroupSize_$type } from "./DropdownGroupSize";
/**
 * @hidden
 */
var DropdownGroup = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DropdownGroup, _super);
    function DropdownGroup() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = new WCNativeHelper();
        _this.d = null;
        return _this;
    }
    Object.defineProperty(DropdownGroup.prototype, "c", {
        get: function () {
            return this.b;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DropdownGroup.prototype, "nativeElement", {
        get: function () {
            return this.d;
        },
        set: function (a) {
            this.d = a;
            this.b.d = this.d;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DropdownGroup.prototype, "a", {
        get: function () {
            var ret_ = this.c.c("size");
            ret_ = enumGetBox(DropdownGroupSize_$type, EnumUtil.getEnumValue(DropdownGroupSize_$type, EnumUtil.parse(DropdownGroupSize_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(DropdownGroupSize_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(DropdownGroupSize_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.c.i("size", value_);
        },
        enumerable: false,
        configurable: true
    });
    DropdownGroup.prototype.f = function () {
        this.nativeElement.connectedCallback();
    };
    DropdownGroup.$t = markType(DropdownGroup, 'DropdownGroup', BaseElement.$);
    return DropdownGroup;
}(BaseElement));
export { DropdownGroup };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/DropdownGroup.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var DropdownGroup = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DropdownGroup, _super);
    function DropdownGroup() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = new WCNativeHelper();
        _this.c = null;
        return _this;
    }
    Object.defineProperty(DropdownGroup.prototype, "b", {
        get: function () {
            return this.a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DropdownGroup.prototype, "nativeElement", {
        get: function () {
            return this.c;
        },
        set: function (a) {
            this.c = a;
            this.a.o = this.c;
        },
        enumerable: false,
        configurable: true
    });
    DropdownGroup.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    DropdownGroup.prototype.e = function () {
        this.nativeElement.connectedCallback();
    };
    DropdownGroup.$t = markType(DropdownGroup, 'DropdownGroup', BaseElement.$);
    return DropdownGroup;
}(BaseElement));
export { DropdownGroup };
